@@ -2,10 +2,9 @@
 
 *** Type definitions ***
 
-rowval = str/int/float
-    (slash(/) means `or`)
-row = dict[str, rowval]
-    lowercase, row represents a row in a table, str is a column name (field)
+RowVal = str | int | float
+Row = dict[str, RowVal]
+    Row represents a row in a table, str is a column name (field)
 """
 
 import os
@@ -57,8 +56,8 @@ class Conn:
         ----------
         table_name: str
 
-        val: Rows/list[row]/Iterable[row]
-            row = dict[str, int/float/str]
+        val: Rows | list[Row] | Iterable[Row]
+            where Row = dict[str, str | int | float]
         """
 
         with _connect(self._dbfile) as dbconn:
@@ -77,8 +76,8 @@ class Rows:
 
             >>> conn['table_name']
 
-        2. Directly pass a list of dicts(list[dict]) or dicts yielding iterator
-        (Iterable[dict])
+        2. Directly pass a list of dicts(list[Row]) or dicts yielding iterator
+        (Iterable[Row])
 
             >>> Rows([d1, d2, ...])
     """
@@ -115,17 +114,17 @@ class Rows:
 
         Parameters
         ----------
-        key: str/slice
+        key: str | slice
 
         Returns
         -------
-        list[rowval]/Rows
+        list[RowVal] | Rows
 
-            if isinstance(key, str) returns list[rowval]
+            if isinstance(key, str) returns list[RowVal]
 
             if isinstance(key, slice) returns Rows
 
-            slicing is similar to list slicing except that negative values
+            slicing here is the same as list slicing except that negative values
             cannot be used
         """
         _raise_exception_if_preceded_by_grouping_methods(self)
@@ -141,7 +140,7 @@ class Rows:
 
         Parameters
         ----------
-        other: Rows/list[row]/Iterable[row]
+        other: Rows | list[Row] | Iterable[Row]
 
         Returns
         -------
@@ -258,7 +257,7 @@ class Rows:
 
         Parameters
         ----------
-        other: Rows/list[row]/Iterable[row]
+        other: Rows | list[Row] | Iterable[Row]
 
         Returns
         -------
@@ -327,7 +326,7 @@ class Rows:
 
         Parameters
         ----------
-        other: Rows/list[row]/Iterable[row]
+        other: Rows | list[Row] | Iterable[Row]
 
         Returns
         -------
@@ -356,14 +355,15 @@ class Rows:
 
     # each column may contain asc or desc
     # ex) 'col1 desc', 'col2 asc'
-    def order(self, *fields_maybe_with_desc):
+    def order(self, fields_maybe_with_desc):
         """Sort according to columns
 
         Parameters
         ----------
-        *fields_maybe_with_desc: list[str]
+        fields_maybe_with_desc: str | list[str]
 
-            str is a field name but it can be with `desc` keyword, for example,
+            comma separated str
+            each field can be with `desc` keyword, for example,
             'col desc'
 
         Returns
@@ -371,7 +371,7 @@ class Rows:
         Rows
         """
         _raise_exception_if_preceded_by_grouping_methods(self)
-
+        fields_maybe_with_desc = _listify(fields_maybe_with_desc)
         newself = copy(self)
 
         # when fetching ordered table from the database.
@@ -475,19 +475,21 @@ class Rows:
         }]
         return newself
 
-    def group(self, *fields):
+    def group(self, fields):
         """Group consecutive rows with the same values for given fields
 
         Parameters
         ----------
-        *fields: list[str]
+        fields: str | list[str]
+
+            comma separated str
 
         Returns
         -------
         Rows
         """
         _raise_exception_if_preceded_by_grouping_methods(self)
-
+        fields = _listify(fields)
         newself = copy(self)
         # pylint: disable=protected-access
         pgen = newself._history[-1]['genfn']
@@ -527,7 +529,7 @@ class Rows:
 
         Parameters
         ----------
-        func: row/Rows -> row/Rows/None
+        func: Row | Rows -> Row | Rows | None
 
             takes row (dict(str, int/float/str) when not grouped
             takes Rows when grouped by methods such as by, group, windowed
@@ -575,17 +577,19 @@ class Rows:
             return gen
         return self._apply(_fn2gen_single(func))
 
+    # name 'by' is inevitable
     # pylint: disable=invalid-name
-    def by(self, *fields_maybe_with_desc):
+    def by(self, fields_maybe_with_desc):
         """Group rows with fields
 
         order columns first and then group
 
         Parameters
         ----------
-        *fields_maybe_with_desc: list[str]
+        fields_maybe_with_desc: str | list[str]
 
-            str is a field name but it can be with `desc` keyword, for example,
+            comma separated str
+            each field can be with `desc` keyword, for example,
             'col desc'
 
         Returns
@@ -593,18 +597,18 @@ class Rows:
         Rows
         """
         _raise_exception_if_preceded_by_grouping_methods(self)
-
+        fields_maybe_with_desc = _listify(fields_maybe_with_desc)
         # need to cut out 'desc', 'asc'
         grouping_fields = [field.split()[0]
                            for field in fields_maybe_with_desc]
-        return self.order(*fields_maybe_with_desc).group(*grouping_fields)
+        return self.order(fields_maybe_with_desc).group(grouping_fields)
 
     def filter(self, pred):
         """Filter rows that the predicate function returns True
 
         Parameters
         ----------
-        pred: row -> bool
+        pred: Row -> bool
 
         Returns
         -------
@@ -627,7 +631,7 @@ class Rows:
 
         Parameters
         ----------
-        **kwargs: dict[str, row -> rowval]
+        **kwargs: dict[str, Row -> RowVal]
 
         Returns
         -------
@@ -686,7 +690,7 @@ class Rows:
 
         Parameters
         ----------
-        **kwargs: dict[str, Rows -> rowval]
+        **kwargs: dict[str, Rows -> RowVal]
 
         Returns
         -------
@@ -699,8 +703,7 @@ class Rows:
         if self._history[-1]['cmd'] == 'group':
             grouping_fields = self._history[-1]['fields']
 
-        # TODO: not sure whether to check if func returns a proper value
-        # (str/int/float)
+        # func type unchecked, it's too expensive.
         def foldfn1(rows):
             rows = Rows(rows)
             row = {}
@@ -721,34 +724,40 @@ class Rows:
         # then self._history[-1]['cmd'] must be 'group', it's check above
         return self._apply(foldfn2)
 
-    def select(self, *fields):
+    def select(self, fields):
         """select fields discarding others
 
         Parameters
         ----------
-        *fields: list[str]
+        fields: str | list[str]
+
+            comma separated str
 
         Returns:
         Rows
         """
         _raise_exception_if_preceded_by_grouping_methods(self)
+        fields = _listify(fields)
 
         def selectfn(row):
             yield {field: row[field] for field in fields}
 
         return self._apply(selectfn)
 
-    def deselect(self, *fields):
+    def deselect(self, fields):
         """Deselect fields
 
         Parameters
         ----------
-        *fields: list[str]
+        fields: str | list[str]
+
+            comma separated str
 
         Returns:
         Rows
         """
         _raise_exception_if_preceded_by_grouping_methods(self)
+        fields = _listify(fields)
 
         fields_set = set(fields)
 
@@ -829,7 +838,7 @@ class Rows:
             return self._merge(joinfn_update_row_ver, other)
         return self._merge(joinfn_new_row_ver, other)
 
-    def distinct(self, *fields):
+    def distinct(self, fields):
         """Returns a Rows with only the first row in each group.
 
         Order and group with fields drop all the others except for the first
@@ -837,13 +846,16 @@ class Rows:
 
         Parameters
         ----------
-        *fields: list[str]
+        fields: str | list[str]
+
+            comma separated str
 
         Returns
         -------
         Rows
         """
         _raise_exception_if_preceded_by_grouping_methods(self)
+        fields = _listify(fields)
 
         def distinctfn(_k, rows):
             # impossible to raise stop iteration here
@@ -851,7 +863,7 @@ class Rows:
             yield next(rows)
 
         # pylint: disable=protected-access
-        return self.by(*fields)._apply(distinctfn)
+        return self.by(fields)._apply(distinctfn)
 
     def windowed(self, chunk_size, step=1):
         """Returns a Rows of a sliding window(rows) with chunk_size skipping
@@ -912,7 +924,7 @@ class Rows:
 
         Parameters
         ----------
-        pred: row -> bool
+        pred: Row -> bool
 
         Returns
         -------
@@ -942,7 +954,7 @@ class Rows:
 
         Parameters
         ----------
-        pred: row -> bool
+        pred: Row -> bool
 
         Returns
         -------
@@ -996,12 +1008,22 @@ class Rows:
 
         Returns
         -------
-        list[row]
+        list[Row]
         """
         _raise_exception_if_preceded_by_grouping_methods(self)
 
+        if self._history[0]['cmd'] == 'fetch':
+            # no need to copy, becaused it's fetched from the database.
+            # pylint: disable=protected-access
+            return list(self._iter())
         # pylint: disable=protected-access
-        return list(self._iter())
+        return [row.copy() for row in self._iter()]
+
+
+def _listify(fields):
+    if isinstance(fields, str):
+        return [field.strip() for field in fields.split(',')]
+    return fields
 
 
 def _insert_statement(table_name, row):
@@ -1016,8 +1038,7 @@ def _insert_statement(table_name, row):
 def _create_statement(table_name, fields):
     """Create table if not exists foo (...)
 
-    Note:
-        Every type is numeric.
+    Every type is numeric.
     """
     schema = ', '.join([field + ' ' + 'numeric' for field in fields])
     return f"create table if not exists {table_name} ({schema})"
