@@ -36,6 +36,7 @@ class TestCore(unittest.TestCase):
         if Path(self.dbfile1).is_file():
             os.remove(self.dbfile1)
 
+
     def test_order_when_no_row(self):
         rs1 = Rows([])
         self.assertEqual(rs1.order('col1').list(), [])
@@ -97,23 +98,30 @@ class TestCore(unittest.TestCase):
     def test_list_mod(self):
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
+        t1 = conn['t1']
+        t1_listed = t1.list()
+        t1_listed[0]['col1'] = 'x'
+        self.assertNotEqual(
+            t1.list()[0]['col1'], 'x'
+        )
+        self.assertEqual(
+            t1_listed[0]['col1'], 'x'
+        )
+
+    def test_list_mod1(self):
+        conn = Conn(self.dbfile)
+        conn['t1'] = self.t1
 
         def tempfn(rs):
             rslist = rs.list()
             for r in rslist:
                 r['col2'] += 1
-
+            # this should not do anything
             return rs
 
         conn['t1_1'] = conn['t1'].by('col1').map(tempfn)
-        self.assertEqual(conn['t1_1'].list(), [
-            {'col1': 'a', 'col2': 5},
-            {'col1': 'a', 'col2': 6},
-            {'col1': 'b', 'col2': 2},
-            {'col1': 'c', 'col2': 4},
-            {'col1': 'c', 'col2': 5},
-            {'col1': 'c', 'col2': 8},
-            {'col1': 'd', 'col2': 3}])
+        self.assertEqual(conn['t1_1'].list(), conn['t1'].list())
+
 
     def test_do_later(self):
         conn = Conn(self.dbfile)
@@ -400,14 +408,14 @@ class TestCore(unittest.TestCase):
 
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
-        conn['t1_1'] = conn['t1'].update(col3=1).by('col1', 'col3')\
+        conn['t1_1'] = conn['t1'].update(col3=1).by('col1, col3')\
             .map(lambda rs: rs)
 
         conn['t1_2'] = conn['t1'].update(col3=1).by('col1').map(lambda rs: rs)
         self.assertEqual(conn['t1_1'].list(), conn['t1_2'].list())
 
         conn['t1_1_double'] = conn['t1_1']\
-            .chain(conn['t1'].update(col3=1).by('col1', 'col3')
+            .chain(conn['t1'].update(col3=1).by('col1, col3')
                    .map(lambda rs: rs))
         conn['t1_1_double2'] = conn['t1_1'].chain(conn['t1_1'])
 
@@ -515,11 +523,11 @@ class TestCore(unittest.TestCase):
             col3=lambda r: r['col1'] + str(r['col2'])
         )
 
-        r = next(conn['t1_1'].select('col1', 'col3')._iter())
+        r = next(conn['t1_1'].select('col1, col3')._iter())
         self.assertEqual(len(r), 2)
 
         # test deselect
-        r = next(conn['t1_1'].deselect('col1', 'col3')._iter())
+        r = next(conn['t1_1'].deselect('col1, col3')._iter())
         self.assertEqual(len(r), 1)
 
     def test_join(self):
@@ -717,15 +725,15 @@ class TestCore(unittest.TestCase):
         conn['t1'] = self.t1
         conn['t1_1'] = conn['t1'].distinct('col1')
         self.assertEqual(len(conn['t1_1'].list()), 4)
-        conn['t1_2'] = conn['t1'].distinct('col1', 'col2')
+        conn['t1_2'] = conn['t1'].distinct('col1, col2')
         self.assertEqual(len(conn['t1_2'].list()), 7)
 
     def test_order(self):
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
 
-        [g1, g2, g3, g4] = [list(xs) for _, xs in conn['t1'].order(
-            'col1', 'col2 desc').group('col1')._iter()]
+        [g1, g2, g3, g4] = [list(xs) for _, xs in conn['t1']\
+            .order('col1, col2 desc').group('col1')._iter()]
         self.assertEqual(
             g1, [{'col1': 'a', 'col2': 5}, {'col1': 'a', 'col2': 4}]
         )
@@ -765,7 +773,7 @@ class TestCore(unittest.TestCase):
             .deselect('col2')
 
         conn['t1_col2sum_groupby_col1_1'] = conn['t1']\
-            .order('col1', 'col2 desc').group('col1')\
+            .order('col1, col2 desc').group('col1')\
             .fold(col2_sum=lambda rs: sum(rs['col2']))\
             .deselect('col2')
 
@@ -792,7 +800,7 @@ class TestCore(unittest.TestCase):
                           {'col1': 'a', 'col2': 6, 'col3': 'a6'}])
 
         conn['t1_1'] = conn['t1'].update(col3=lambda r: r['col2'] + 1)\
-            .deselect('col1', 'col2')
+            .deselect('col1, col2')
 
         self.assertEqual(conn['t1_1'].list(),
                          [{'col3': 5}, {'col3': 6}, {'col3': 2}])
